Description: A statistical machine learning toolbox for estimating models, distributions, and functions with context-specific parameters.

# Contextualized.ML

A statistical machine learning toolbox for estimating models, distributions, and functions with context-specific parameters.

Get Started
Learn More

State-of-the-art methods to estimate and explore context-specific models

Comprehensive support for multiple types of models and meta-models, with training and analysis tools

Building blocks to support extending meta-models to contextualize your application-specific mdoel

## Why ContextualizedML?

###

###### Easy usage

Access state-of-the-art techniques through an open unified API and rich visualizations.

###### Flexible and customizable

Understand models using a wide range of explainers and techniques using interactive visuals. PyTorch Choose your algorithm and easily experiment with combinations of algorithms.

###### Community-driven open source toolkit

Join the community, request and contribute improvements to make your model the best it can be.

## Model Types

### Contextualized Regression

Do the features which predict an outcome change from sample to sample?

### Contextualized Bayesian Networks

Does the joint distribution of features change from sample to sample?

### Contextualized Correlation

Do the correlations between features change from sample to sample?

## What You Can Do With ContextualizedML

### Find Hidden Heterogeneity

- Identify changes in data distributions with Contextualized Bayesian Networks
- Identify changes in feature correlations with Contextualized Correlation Networks

### Connect Heterogeneity to Outcomes

- Identify Heterogeneous predictors of outcomes with Contextualized Regression
- Cluster samples according to reasons for outcome

## Who Can Benefit from ContextualizedML?

### Data Scientists

Understand heterogeneity hiding in your dataset.

### Scientists

Understand heterogenetiy in the observed populations.

### ML Engineers

Build models which adapt to new environments and contexts.

### ML Researchers

Contextualize your new models.

# Getting Started

Install ContextualizedML

## Contribute to ContextualizedML

We encourage you to join the effort and contribute feedback, algorithms, ideas and more, so we can improve the toolkit together!

Contribute